==> babel-plugin-transform-scss-import-to-string-0.1.0.tgz: package/lib/index.js <==
const { resolve, dirname } = require('path');
const { readFileSync } = require('fs');
const { renderSync } = require('node-sass');

const isImportDefaultSpecifier = node => node.type === 'ImportDefaultSpecifier';

/**
 * This babel plugin transpiles scss import declaration with *.scss mask and
 * replaces it with const variable declaration with raw css string
 */
function transformScssToString(babel) {
  const { types: t } = babel;
  return {
    name: 'babel-plugin-transform-scss-import-to-string',
    visitor: {
      ImportDeclaration(path, { file: { opts: { filename } } }) {
        // Filter *.scss imports
        if (!/\.scss$/.test(path.node.source.value)) return;
        // Get full path to file and transpile it
        const fullScssFilePath = resolve(
          dirname(filename),
          path.node.source.value
        );
        const rawScssContent = readFileSync(fullScssFilePath).toString();
        const sassResult = renderSync({
          data: rawScssContent,
          sourceMap: false,
        });
        const transpiledContent = sassResult.css.toString() || '';
        // Extract import name
        const defaultImportNode = path.node.specifiers.find(
          isImportDefaultSpecifier
        );
        if (!defaultImportNode) return;
        const defaultImportName = defaultImportNode.local.name;
        // Replace import with hardcoded value
        path.replaceWith(
          t.variableDeclaration('const', [
            t.variableDeclarator(
              t.identifier(defaultImportName),
              t.stringLiteral(transpiledContent)
            ),
          ])
        );
      },
    },
  };
}

module.exports = transformScssToString;

==> babel-plugin-transform-scss-import-to-string-0.1.1.tgz: package/lib/index.js <==
const { resolve, dirname, join } = require('path');
const { readFileSync } = require('fs');
const { renderSync } = require('node-sass');

const isImportDefaultSpecifier = node => node.type === 'ImportDefaultSpecifier';

/**
 * This babel plugin transpiles scss import declaration with *.scss mask and
 * replaces it with const variable declaration with raw css string
 */
function transformScssToString(babel) {
  const { types: t } = babel;
  return {
    name: 'babel-plugin-transform-scss-import-to-string',
    visitor: {
      ImportDeclaration(path, { file: { opts: { filename } } }) {
        // Filter *.scss imports
        if (!/\.scss$/.test(path.node.source.value)) return;
        // Get full path to file and transpile it
        const scssFileDirectory = resolve(dirname(filename));
        const fullScssFilePath = join(
          scssFileDirectory,
          path.node.source.value
        );
        const rawScssContent = readFileSync(fullScssFilePath).toString();
        const projectRoot = process.cwd();
        const nodeModulesPath = join(projectRoot, 'node_modules');
        const sassResult = renderSync({
          data: rawScssContent,
          sourceMap: false,
          includePaths: [nodeModulesPath, scssFileDirectory, projectRoot],
        });
        const transpiledContent = sassResult.css.toString() || '';
        // Extract import name
        const defaultImportNode = path.node.specifiers.find(
          isImportDefaultSpecifier
        );
        if (!defaultImportNode) return;
        const defaultImportName = defaultImportNode.local.name;
        // Replace import with hardcoded value
        path.replaceWith(
          t.variableDeclaration('const', [
            t.variableDeclarator(
              t.identifier(defaultImportName),
              t.stringLiteral(transpiledContent)
            ),
          ])
        );
      },
    },
  };
}

module.exports = transformScssToString;
